==> haskell-tasty-sugar-2.1.0.0-58-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-sugar.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 z-tasty-sugar-z-tasty-sugar-internal
version:              2.1.0.0
package-name:         tasty-sugar
lib-name:             tasty-sugar-internal
id:
    tasty-sugar-2.1.0.0-7lMBLBWzXsM5NKbz1Q4CSL-tasty-sugar-internal

key:
    tasty-sugar-2.1.0.0-7lMBLBWzXsM5NKbz1Q4CSL-tasty-sugar-internal

license:              ISC
copyright:            Kevin Quick, 2019-2022
maintainer:           kquick@galois.com
author:               Kevin Quick
homepage:             https://github.com/kquick/tasty-sugar
synopsis:             Tests defined by Search Using Golden Answer References
description:

    A tasty testing framework that builds individual test configurations
    from a set of input files and expected results (golden) files along
    with associated files, where multiple expected results and
    associated files for each input file can be parameterized by
    filename.

    Additionally a tasty ingredient is supplied that can be used to show
    the search process and resulting test configurations without
    actually running the tests.

category:             Testing
abi:                  7bd88e8b96e14c35affe3f24926585c2
exposed-modules:
    Test.Tasty.Sugar.Analysis Test.Tasty.Sugar.AssocCheck
    Test.Tasty.Sugar.Candidates Test.Tasty.Sugar.ExpectCheck
    Test.Tasty.Sugar.Iterations Test.Tasty.Sugar.ParamCheck
    Test.Tasty.Sugar.Report Test.Tasty.Sugar.Types

import-dirs:          /usr/lib/ghc-9.2.8/site-local/tasty-sugar-2.1.0.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/tasty-sugar-2.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-sugar
hs-libraries:
    HStasty-sugar-2.1.0.0-7lMBLBWzXsM5NKbz1Q4CSL-tasty-sugar-internal

depends:
    base-4.16.4.0 containers-0.6.5.1 directory-1.3.6.2
    filemanip-0.3.6.3-CKLIqGXr0nRFUsshmJl5O9 filepath-1.4.2.2
    kvitable-1.0.3.0-CwkxPWw1wde2xTRc0wEuUb
    logict-0.7.1.0-KxfZbQaOAFH4gJopXvpeoQ
    microlens-0.4.13.1-HPplyG5VOciEIF62YegSgA mtl-2.2.2
    parallel-3.2.2.0-KgDyPHm89eYAjQsIhXthC1
    prettyprinter-1.7.1-BkswhB91sqXDALbzFLS4rf text-1.2.5.0

haddock-interfaces:   /usr/share/doc/haskell-tasty-sugar/html/tasty-sugar.haddock
haddock-html:         /usr/share/doc/haskell-tasty-sugar/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tasty-sugar
version:              2.1.0.0
visibility:           public
id:                   tasty-sugar-2.1.0.0-E8cL8NM4g8sJojLodRBglb
key:                  tasty-sugar-2.1.0.0-E8cL8NM4g8sJojLodRBglb
license:              ISC
copyright:            Kevin Quick, 2019-2022
maintainer:           kquick@galois.com
author:               Kevin Quick
homepage:             https://github.com/kquick/tasty-sugar
synopsis:             Tests defined by Search Using Golden Answer References
description:

    A tasty testing framework that builds individual test configurations
    from a set of input files and expected results (golden) files along
    with associated files, where multiple expected results and
    associated files for each input file can be parameterized by
    filename.

    Additionally a tasty ingredient is supplied that can be used to show
    the search process and resulting test configurations without
    actually running the tests.

category:             Testing
abi:                  e2f83e3981c1ddd6d54e4a644d66b24a
exposed:              True
exposed-modules:      Test.Tasty.Sugar
import-dirs:          /usr/lib/ghc-9.2.8/site-local/tasty-sugar-2.1.0.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/tasty-sugar-2.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-sugar
hs-libraries:         HStasty-sugar-2.1.0.0-E8cL8NM4g8sJojLodRBglb
depends:
    base-4.16.4.0 containers-0.6.5.1 directory-1.3.6.2
    filemanip-0.3.6.3-CKLIqGXr0nRFUsshmJl5O9 filepath-1.4.2.2
    logict-0.7.1.0-KxfZbQaOAFH4gJopXvpeoQ
    optparse-applicative-0.17.1.0-AgMeQrX7nmlDOnX2xcegDb
    prettyprinter-1.7.1-BkswhB91sqXDALbzFLS4rf
    tasty-1.4.3-2gR9WDhWbJHGLAofnQHAx7
    tasty-sugar-2.1.0.0-7lMBLBWzXsM5NKbz1Q4CSL-tasty-sugar-internal
    text-1.2.5.0

haddock-interfaces:   /usr/share/doc/haskell-tasty-sugar/html/tasty-sugar.haddock
haddock-html:         /usr/share/doc/haskell-tasty-sugar/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-sugar-2.1.0.0-59-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-sugar.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 z-tasty-sugar-z-tasty-sugar-internal
version:              2.1.0.0
package-name:         tasty-sugar
lib-name:             tasty-sugar-internal
id:
    tasty-sugar-2.1.0.0-Dug71BzaR53I2HdtuM38x-tasty-sugar-internal

key:
    tasty-sugar-2.1.0.0-Dug71BzaR53I2HdtuM38x-tasty-sugar-internal

license:              ISC
copyright:            Kevin Quick, 2019-2022
maintainer:           kquick@galois.com
author:               Kevin Quick
homepage:             https://github.com/kquick/tasty-sugar
synopsis:             Tests defined by Search Using Golden Answer References
description:

    A tasty testing framework that builds individual test configurations
    from a set of input files and expected results (golden) files along
    with associated files, where multiple expected results and
    associated files for each input file can be parameterized by
    filename.

    Additionally a tasty ingredient is supplied that can be used to show
    the search process and resulting test configurations without
    actually running the tests.

category:             Testing
abi:                  f2a3e4e3532dc8e5fa3f08a3b678250e
exposed-modules:
    Test.Tasty.Sugar.Analysis Test.Tasty.Sugar.AssocCheck
    Test.Tasty.Sugar.Candidates Test.Tasty.Sugar.ExpectCheck
    Test.Tasty.Sugar.Iterations Test.Tasty.Sugar.ParamCheck
    Test.Tasty.Sugar.Report Test.Tasty.Sugar.Types

import-dirs:          /usr/lib/ghc-9.2.8/site-local/tasty-sugar-2.1.0.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/tasty-sugar-2.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-sugar
hs-libraries:
    HStasty-sugar-2.1.0.0-Dug71BzaR53I2HdtuM38x-tasty-sugar-internal

depends:
    base-4.16.4.0 containers-0.6.5.1 directory-1.3.6.2
    filemanip-0.3.6.3-BDvSeYvhO6K1QDebkaFwk7 filepath-1.4.2.2
    kvitable-1.0.3.0-H1oCT9stXmS72aljTQujn3
    logict-0.7.1.0-KxfZbQaOAFH4gJopXvpeoQ
    microlens-0.4.13.1-HPplyG5VOciEIF62YegSgA mtl-2.2.2
    parallel-3.2.2.0-KgDyPHm89eYAjQsIhXthC1
    prettyprinter-1.7.1-HEZISHQd8iY9qtmwIqnFLW text-1.2.5.0

haddock-interfaces:   /usr/share/doc/haskell-tasty-sugar/html/tasty-sugar.haddock
haddock-html:         /usr/share/doc/haskell-tasty-sugar/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tasty-sugar
version:              2.1.0.0
visibility:           public
id:                   tasty-sugar-2.1.0.0-2A27ZA6qNV2CeH8CI6FK1v
key:                  tasty-sugar-2.1.0.0-2A27ZA6qNV2CeH8CI6FK1v
license:              ISC
copyright:            Kevin Quick, 2019-2022
maintainer:           kquick@galois.com
author:               Kevin Quick
homepage:             https://github.com/kquick/tasty-sugar
synopsis:             Tests defined by Search Using Golden Answer References
description:

    A tasty testing framework that builds individual test configurations
    from a set of input files and expected results (golden) files along
    with associated files, where multiple expected results and
    associated files for each input file can be parameterized by
    filename.

    Additionally a tasty ingredient is supplied that can be used to show
    the search process and resulting test configurations without
    actually running the tests.

category:             Testing
abi:                  4bc96f4c384be47841b3f2a7aef6506d
exposed:              True
exposed-modules:      Test.Tasty.Sugar
import-dirs:          /usr/lib/ghc-9.2.8/site-local/tasty-sugar-2.1.0.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/tasty-sugar-2.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-sugar
hs-libraries:         HStasty-sugar-2.1.0.0-2A27ZA6qNV2CeH8CI6FK1v
depends:
    base-4.16.4.0 containers-0.6.5.1 directory-1.3.6.2
    filemanip-0.3.6.3-BDvSeYvhO6K1QDebkaFwk7 filepath-1.4.2.2
    logict-0.7.1.0-KxfZbQaOAFH4gJopXvpeoQ
    optparse-applicative-0.17.1.0-AgMeQrX7nmlDOnX2xcegDb
    prettyprinter-1.7.1-HEZISHQd8iY9qtmwIqnFLW
    tasty-1.4.3-2gR9WDhWbJHGLAofnQHAx7
    tasty-sugar-2.1.0.0-Dug71BzaR53I2HdtuM38x-tasty-sugar-internal
    text-1.2.5.0

haddock-interfaces:   /usr/share/doc/haskell-tasty-sugar/html/tasty-sugar.haddock
haddock-html:         /usr/share/doc/haskell-tasty-sugar/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
